==> haskell-data-hash-0.2.0.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-hash
version:              0.2.0.1
visibility:           public
id:                   data-hash-0.2.0.1-Av4nRZeoeSkBOHMuDYmrkN
key:                  data-hash-0.2.0.1-Av4nRZeoeSkBOHMuDYmrkN
license:              BSD-3-Clause
maintainer:           jcpetruzza@gmail.com
synopsis:             Combinators for building fast hashing functions.
description:
    Combinators for building fast hashing functions. Includes
    hashing functions for all basic Haskell98 types.

category:             Data
abi:                  7087aee6810ae8d7d067577a9b66fc4f
exposed:              True
exposed-modules:      Data.Hash Data.Hash.Rolling
hidden-modules:       Data.Hash.Base Data.Hash.Instances
import-dirs:          /usr/lib/ghc-8.8.3/site-local/data-hash-0.2.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/data-hash-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/data-hash-0.2.0.1
hs-libraries:         HSdata-hash-0.2.0.1-Av4nRZeoeSkBOHMuDYmrkN
depends:              array-0.5.4.0 base-4.13.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-data-hash/html/data-hash.haddock
haddock-html:         /usr/share/doc/haskell-data-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-hash-0.2.0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-hash
version:              0.2.0.1
visibility:           public
id:                   data-hash-0.2.0.1-As7pIFjiUiSFblwGBrcm4z
key:                  data-hash-0.2.0.1-As7pIFjiUiSFblwGBrcm4z
license:              BSD-3-Clause
maintainer:           jcpetruzza@gmail.com
synopsis:             Combinators for building fast hashing functions.
description:
    Combinators for building fast hashing functions. Includes
    hashing functions for all basic Haskell98 types.

category:             Data
abi:                  e2b6b967836f4894a1838e8c399d8f8e
exposed:              True
exposed-modules:      Data.Hash Data.Hash.Rolling
hidden-modules:       Data.Hash.Base Data.Hash.Instances
import-dirs:          /usr/lib/ghc-8.10.1/site-local/data-hash-0.2.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/data-hash-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/data-hash-0.2.0.1
hs-libraries:         HSdata-hash-0.2.0.1-As7pIFjiUiSFblwGBrcm4z
depends:              array-0.5.4.0 base-4.14.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-data-hash/html/data-hash.haddock
haddock-html:         /usr/share/doc/haskell-data-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
